@@ -46,7 +46,7 @@ TextTestResult::TextTestResult(const std::string& ignore):
 				ifs.close();
 			}
 		}
-		catch (std::exception e)
+		catch (std::exception& e)
 		{
 			std::cout << e.what() << std::endl;
 		}
@@ -126,6 +126,7 @@ void TextTestResult::addError(Test* test, CppUnitException* e)
 	else
 	{
 		_ostr << "ERROR (ignored)" << std::flush;
+		delete e;
 	}
 }
 
@@ -140,6 +141,7 @@ void TextTestResult::addFailure(Test* test, CppUnitException* e)
 	else
 	{
 		_ostr << "FAILURE (ignored)" << std::flush;
+		delete e;
 	}
 }
 
@@ -147,7 +149,7 @@ void TextTestResult::addFailure(Test* test, CppUnitException* e)
 void TextTestResult::startTest(Test* test)
 {
 	TestResult::startTest(test);
-	_ostr << "\n" << shortName(test->toString()) << ": ";
+	_ostr << "\n" << shortName(test->toString()) << ": " << std::flush;
 }
 
 
