@@ -50,8 +50,6 @@ namespace
 			return RSA_PKCS1_PADDING;
 		case RSA_PADDING_PKCS1_OAEP:
 			return RSA_PKCS1_OAEP_PADDING;
-		case RSA_PADDING_SSLV23:
-			return RSA_SSLV23_PADDING;
 		case RSA_PADDING_NONE:
 			return RSA_NO_PADDING;
 		default:
@@ -116,7 +114,6 @@ namespace
 		switch (_paddingMode)
 		{
 		case RSA_PADDING_PKCS1:
-		case RSA_PADDING_SSLV23:
 			size -= 11;
 			break;
 		case RSA_PADDING_PKCS1_OAEP:
@@ -329,13 +326,13 @@ RSACipherImpl::~RSACipherImpl()
 }
 
 
-CryptoTransform* RSACipherImpl::createEncryptor()
+CryptoTransform::Ptr RSACipherImpl::createEncryptor()
 {
 	return new RSAEncryptImpl(_key.impl()->getRSA(), _paddingMode);
 }
 
 
-CryptoTransform* RSACipherImpl::createDecryptor()
+CryptoTransform::Ptr RSACipherImpl::createDecryptor()
 {
 	return new RSADecryptImpl(_key.impl()->getRSA(), _paddingMode);
 }
