@@ -21,43 +21,49 @@ namespace Crypto {
 
 
 RSAKey::RSAKey(const EVPPKey& key):
-	KeyPair(new RSAKeyImpl(key)),
-	_pImpl(KeyPair::impl().cast<RSAKeyImpl>())
+	KeyPair(new RSAKeyImpl(key))
 {
 }
 
 
 RSAKey::RSAKey(const X509Certificate& cert):
-	KeyPair(new RSAKeyImpl(cert)),
-	_pImpl(KeyPair::impl().cast<RSAKeyImpl>())
+	KeyPair(new RSAKeyImpl(cert))
 {
 }
 
 
 RSAKey::RSAKey(const PKCS12Container& cont):
-	KeyPair(new RSAKeyImpl(cont)),
-	_pImpl(KeyPair::impl().cast<RSAKeyImpl>())
+	KeyPair(new RSAKeyImpl(cont))
 {
 }
 
 
 RSAKey::RSAKey(KeyLength keyLength, Exponent exp):
-	KeyPair(new RSAKeyImpl(keyLength, (exp == EXP_LARGE) ? RSA_F4 : RSA_3)),
-	_pImpl(KeyPair::impl().cast<RSAKeyImpl>())
+	KeyPair(new RSAKeyImpl(keyLength, (exp == EXP_LARGE) ? RSA_F4 : RSA_3))
 {
 }
 
 
 RSAKey::RSAKey(const std::string& publicKeyFile, const std::string& privateKeyFile, const std::string& privateKeyPassphrase):
-	KeyPair(new RSAKeyImpl(publicKeyFile, privateKeyFile, privateKeyPassphrase)),
-	_pImpl(KeyPair::impl().cast<RSAKeyImpl>())
+	KeyPair(new RSAKeyImpl(publicKeyFile, privateKeyFile, privateKeyPassphrase))
 {
 }
 
 
 RSAKey::RSAKey(std::istream* pPublicKeyStream, std::istream* pPrivateKeyStream, const std::string& privateKeyPassphrase):
-	KeyPair(new RSAKeyImpl(pPublicKeyStream, pPrivateKeyStream, privateKeyPassphrase)),
-	_pImpl(KeyPair::impl().cast<RSAKeyImpl>())
+	KeyPair(new RSAKeyImpl(pPublicKeyStream, pPrivateKeyStream, privateKeyPassphrase))
+{
+}
+
+
+RSAKey::RSAKey(const RSAKey& other):
+	KeyPair(other)
+{
+}
+
+
+RSAKey::RSAKey(RSAKey&& other) noexcept:
+	KeyPair(std::move(other))
 {
 }
 
@@ -66,22 +72,37 @@ RSAKey::~RSAKey()
 {
 }
 
+
+RSAKey& RSAKey::operator = (const RSAKey& other)
+{
+	KeyPair::operator = (other);
+	return *this;
+}
+
+
+RSAKey& RSAKey::operator = (RSAKey&& other) noexcept
+{
+	KeyPair::operator = (std::move(other));
+	return *this;
+}
+
+
 RSAKeyImpl::ByteVec RSAKey::modulus() const
 {
-	return _pImpl->modulus();
+	return impl()->modulus();
 }
 
 
 RSAKeyImpl::ByteVec RSAKey::encryptionExponent() const
 {
-	return _pImpl->encryptionExponent();
+	return impl()->encryptionExponent();
 }
 
 
 RSAKeyImpl::ByteVec RSAKey::decryptionExponent() const
 {
-	return _pImpl->decryptionExponent();
+	return impl()->decryptionExponent();
 }
 
 
-} } // namespace Poco::Crypto
\ No newline at end of file
+} } // namespace Poco::Crypto
