@@ -19,6 +19,7 @@
 
 
 #include "Poco/Foundation.h"
+#include <mysql/mysql.h>
 
 
 //
@@ -50,10 +51,15 @@
 //
 // Automatically link Data library.
 //
-#if defined(_MSC_VER)
-	#if !defined(POCO_NO_AUTOMATIC_LIBS) && !defined(MySQL_EXPORTS)
+#if defined(_MSC_VER) && !defined(POCO_NO_AUTOMATIC_LIBS)
+	#if !defined(MySQL_EXPORTS)
 		#pragma comment(lib, "PocoDataMySQL" POCO_LIB_SUFFIX)
 	#endif
+	#if defined(LIBMARIADB)
+		#pragma comment(lib, "libmariadb")
+	#else
+		#pragma comment(lib, "libmysql")
+	#endif
 #endif
 
 
