@@ -20,10 +20,7 @@
 
 #include "Poco/Data/MySQL/MySQL.h"
 #include "Poco/Data/Session.h"
-
-
-struct st_mysql;
-typedef struct st_mysql MYSQL;
+#include <mysql/mysql.h>
 
 
 namespace Poco {
@@ -35,7 +32,6 @@ class MySQL_API Utility
 	/// Various utility functions for MySQL.
 {
 public:
-
 	static std::string serverInfo(MYSQL* pHandle);
 		/// Returns server info.
 
