@@ -80,6 +80,10 @@ void Binder::freeMemory()
 	UTF16CharPtrVec::iterator endUTF16Chr = _utf16CharPtrs.end();
 	for (; itUTF16Chr != endUTF16Chr; ++itUTF16Chr) std::free(*itUTF16Chr);
 
+	UUIDMap::iterator itUUID = _uuids.begin();
+	UUIDMap::iterator itUUIDEnd = _uuids.end();
+	for(; itUUID != itUUIDEnd; ++itUUID) std::free(itUUID->first);
+
 	BoolPtrVec::iterator itBool = _boolPtrs.begin();
 	BoolPtrVec::iterator endBool = _boolPtrs.end();
 	for (; itBool != endBool; ++itBool) delete [] *itBool;
@@ -129,15 +133,15 @@ void Binder::bind(std::size_t pos, const std::string& val, Direction dir)
 
 	_lengthIndicator.push_back(pLenIn);
 
-	if (Utility::isError(SQLBindParameter(_rStmt, 
-		(SQLUSMALLINT) pos + 1, 
-		toODBCDirection(dir), 
-		SQL_C_CHAR, 
-		Connector::stringBoundToLongVarChar() ? SQL_LONGVARCHAR : SQL_VARCHAR, 
+	if (Utility::isError(SQLBindParameter(_rStmt,
+		(SQLUSMALLINT) pos + 1,
+		toODBCDirection(dir),
+		SQL_C_CHAR,
+		Connector::stringBoundToLongVarChar() ? SQL_LONGVARCHAR : SQL_VARCHAR,
 		(SQLUINTEGER) colSize,
 		0,
-		pVal, 
-		(SQLINTEGER) size, 
+		pVal,
+		(SQLINTEGER) size,
 		_lengthIndicator.back())))
 	{
 		throw StatementException(_rStmt, "SQLBindParameter(std::string)");
@@ -206,22 +210,22 @@ void Binder::bind(std::size_t pos, const Date& val, Direction dir)
 
 	SQL_DATE_STRUCT* pDS = new SQL_DATE_STRUCT;
 	Utility::dateSync(*pDS, val);
-	
+
 	_dates.insert(DateMap::value_type(pDS, const_cast<Date*>(&val)));
 
 	SQLINTEGER colSize = 0;
 	SQLSMALLINT decDigits = 0;
 	getColSizeAndPrecision(pos, SQL_TYPE_DATE, colSize, decDigits);
 
-	if (Utility::isError(SQLBindParameter(_rStmt, 
-		(SQLUSMALLINT) pos + 1, 
-		toODBCDirection(dir), 
-		SQL_C_TYPE_DATE, 
-		SQL_TYPE_DATE, 
+	if (Utility::isError(SQLBindParameter(_rStmt,
+		(SQLUSMALLINT) pos + 1,
+		toODBCDirection(dir),
+		SQL_C_TYPE_DATE,
+		SQL_TYPE_DATE,
 		colSize,
 		decDigits,
-		(SQLPOINTER) pDS, 
-		0, 
+		(SQLPOINTER) pDS,
+		0,
 		_lengthIndicator.back())))
 	{
 		throw StatementException(_rStmt, "SQLBindParameter(Date)");
@@ -239,22 +243,22 @@ void Binder::bind(std::size_t pos, const Time& val, Direction dir)
 
 	SQL_TIME_STRUCT* pTS = new SQL_TIME_STRUCT;
 	Utility::timeSync(*pTS, val);
-	
+
 	_times.insert(TimeMap::value_type(pTS, const_cast<Time*>(&val)));
 
 	SQLINTEGER colSize = 0;
 	SQLSMALLINT decDigits = 0;
 	getColSizeAndPrecision(pos, SQL_TYPE_TIME, colSize, decDigits);
 
-	if (Utility::isError(SQLBindParameter(_rStmt, 
-		(SQLUSMALLINT) pos + 1, 
-		toODBCDirection(dir), 
-		SQL_C_TYPE_TIME, 
-		SQL_TYPE_TIME, 
+	if (Utility::isError(SQLBindParameter(_rStmt,
+		(SQLUSMALLINT) pos + 1,
+		toODBCDirection(dir),
+		SQL_C_TYPE_TIME,
+		SQL_TYPE_TIME,
 		colSize,
 		decDigits,
-		(SQLPOINTER) pTS, 
-		0, 
+		(SQLPOINTER) pTS,
+		0,
 		_lengthIndicator.back())))
 	{
 		throw StatementException(_rStmt, "SQLBindParameter(Time)");
@@ -279,15 +283,15 @@ void Binder::bind(std::size_t pos, const Poco::DateTime& val, Direction dir)
 	SQLSMALLINT decDigits = 0;
 	getColSizeAndPrecision(pos, SQL_TYPE_TIMESTAMP, colSize, decDigits);
 
-	if (Utility::isError(SQLBindParameter(_rStmt, 
-		(SQLUSMALLINT) pos + 1, 
-		toODBCDirection(dir), 
-		SQL_C_TYPE_TIMESTAMP, 
-		SQL_TYPE_TIMESTAMP, 
+	if (Utility::isError(SQLBindParameter(_rStmt,
+		(SQLUSMALLINT) pos + 1,
+		toODBCDirection(dir),
+		SQL_C_TYPE_TIMESTAMP,
+		SQL_TYPE_TIMESTAMP,
 		colSize,
 		decDigits,
-		(SQLPOINTER) pTS, 
-		0, 
+		(SQLPOINTER) pTS,
+		0,
 		_lengthIndicator.back())))
 	{
 		throw StatementException(_rStmt, "SQLBindParameter(DateTime)");
@@ -295,6 +299,38 @@ void Binder::bind(std::size_t pos, const Poco::DateTime& val, Direction dir)
 }
 
 
+void Binder::bind(std::size_t pos, const UUID& val, Direction dir)
+{
+	SQLINTEGER size = (SQLINTEGER) 16;
+	SQLLEN* pLenIn = new SQLLEN;
+	*pLenIn = size;
+
+	_lengthIndicator.push_back(pLenIn);
+
+	char* pUUID = new char[16];
+	val.copyTo(pUUID);
+
+	_uuids.insert(UUIDMap::value_type(pUUID, const_cast<UUID*>(&val)));
+
+	SQLINTEGER colSize = 0;
+	SQLSMALLINT decDigits = 0;
+
+	if (Utility::isError(SQLBindParameter(_rStmt,
+		(SQLUSMALLINT) pos + 1,
+		toODBCDirection(dir),
+		SQL_C_BINARY,
+		SQL_GUID,
+		colSize,
+		decDigits,
+		(SQLPOINTER) pUUID,
+		0,
+		_lengthIndicator.back())))
+	{
+		throw StatementException(_rStmt, "SQLBindParameter(UUID)");
+	}
+}
+
+
 void Binder::bind(std::size_t pos, const NullData& val, Direction dir)
 {
 	if (isOutBound(dir) || !isInBound(dir))
@@ -311,15 +347,15 @@ void Binder::bind(std::size_t pos, const NullData& val, Direction dir)
 	SQLSMALLINT decDigits = 0;
 	getColSizeAndPrecision(pos, SQL_C_STINYINT, colSize, decDigits);
 
-	if (Utility::isError(SQLBindParameter(_rStmt, 
-		(SQLUSMALLINT) pos + 1, 
-		SQL_PARAM_INPUT, 
-		SQL_C_STINYINT, 
-		Utility::sqlDataType(SQL_C_STINYINT), 
+	if (Utility::isError(SQLBindParameter(_rStmt,
+		(SQLUSMALLINT) pos + 1,
+		SQL_PARAM_INPUT,
+		SQL_C_STINYINT,
+		Utility::sqlDataType(SQL_C_STINYINT),
 		colSize,
 		decDigits,
-		0, 
-		0, 
+		0,
+		0,
 		_lengthIndicator.back())))
 	{
 		throw StatementException(_rStmt, "SQLBindParameter()");
@@ -334,7 +370,7 @@ std::size_t Binder::parameterSize(SQLPOINTER pAddr) const
 
 	it = _outParams.find(pAddr);
 	if (it != _outParams.end()) return it->second;
-	
+
 	throw NotFoundException("Requested data size not found.");
 }
 
@@ -350,7 +386,7 @@ SQLSMALLINT Binder::toODBCDirection(Direction dir) const
 	bool in = isInBound(dir);
 	bool out = isOutBound(dir);
 	SQLSMALLINT ioType = SQL_PARAM_TYPE_UNKNOWN;
-	if (in && out) ioType = SQL_PARAM_INPUT_OUTPUT; 
+	if (in && out) ioType = SQL_PARAM_INPUT_OUTPUT;
 	else if(in)    ioType = SQL_PARAM_INPUT;
 	else if(out)   ioType = SQL_PARAM_OUTPUT;
 	else throw Poco::IllegalStateException("Binder not bound (must be [in] OR [out]).");
@@ -365,7 +401,7 @@ void Binder::synchronize()
 	{
 		DateMap::iterator it = _dates.begin();
 		DateMap::iterator end = _dates.end();
-		for(; it != end; ++it) 
+		for(; it != end; ++it)
 			Utility::dateSync(*it->second, *it->first);
 	}
 
@@ -373,7 +409,7 @@ void Binder::synchronize()
 	{
 		TimeMap::iterator it = _times.begin();
 		TimeMap::iterator end = _times.end();
-		for(; it != end; ++it) 
+		for(; it != end; ++it)
 			Utility::timeSync(*it->second, *it->first);
 	}
 
@@ -381,7 +417,7 @@ void Binder::synchronize()
 	{
 		TimestampMap::iterator it = _timestamps.begin();
 		TimestampMap::iterator end = _timestamps.end();
-		for(; it != end; ++it) 
+		for(; it != end; ++it)
 			Utility::dateTimeSync(*it->second, *it->first);
 	}
 
@@ -392,6 +428,14 @@ void Binder::synchronize()
 		for(; it != end; ++it)
 			it->second->assign(it->first, std::strlen(it->first));
 	}
+
+	if (_uuids.size())
+	{
+		UUIDMap::iterator it = _uuids.begin();
+		UUIDMap::iterator end = _uuids.end();
+		for(; it != end; ++it)
+			it->second->copyFrom(it->first);
+	}
 }
 
 
@@ -405,6 +449,7 @@ void Binder::reset()
 	_times.clear();
 	_timestamps.clear();
 	_strings.clear();
+	_uuids.clear();
 	_dateVecVec.clear();
 	_timeVecVec.clear();
 	_dateTimeVecVec.clear();
@@ -415,9 +460,9 @@ void Binder::reset()
 }
 
 
-void Binder::getColSizeAndPrecision(std::size_t pos, 
-	SQLSMALLINT cDataType, 
-	SQLINTEGER& colSize, 
+void Binder::getColSizeAndPrecision(std::size_t pos,
+	SQLSMALLINT cDataType,
+	SQLINTEGER& colSize,
 	SQLSMALLINT& decDigits,
 	std::size_t actualSize)
 {
@@ -448,9 +493,9 @@ void Binder::getColSizeAndPrecision(std::size_t pos,
 		colSize = (SQLINTEGER) p.columnSize();
 		decDigits = (SQLSMALLINT) p.decimalDigits();
 		return;
-	} 
+	}
 	catch (StatementException&)
-	{ 
+	{
 	}
 
 	try
@@ -459,9 +504,9 @@ void Binder::getColSizeAndPrecision(std::size_t pos,
 		colSize = (SQLINTEGER) c.length();
 		decDigits = (SQLSMALLINT) c.precision();
 		return;
-	} 
-	catch (StatementException&) 
-	{ 
+	}
+	catch (StatementException&)
+	{
 	}
 
 	// last check, just in case
@@ -505,7 +550,7 @@ void Binder::getColumnOrParameterSize(std::size_t pos, SQLINTEGER& size)
 		if (!Utility::isError(SQLGetStmtAttr(_rStmt, SQL_ATTR_IMP_PARAM_DESC, &hIPD, SQL_IS_POINTER, 0)))
 		{
 			SQLUINTEGER sz = 0;
-			if (!Utility::isError(SQLGetDescField(hIPD, (SQLSMALLINT) pos + 1, SQL_DESC_LENGTH, &sz, SQL_IS_UINTEGER, 0)) && 
+			if (!Utility::isError(SQLGetDescField(hIPD, (SQLSMALLINT) pos + 1, SQL_DESC_LENGTH, &sz, SQL_IS_UINTEGER, 0)) &&
 				sz > 0)
 			{
 				size = sz;
@@ -529,7 +574,7 @@ void Binder::setParamSetSize(std::size_t length)
 {
 	if (0 == _paramSetSize)
 	{
-		if (Utility::isError(Poco::Data::ODBC::SQLSetStmtAttr(_rStmt, SQL_ATTR_PARAM_BIND_TYPE, SQL_PARAM_BIND_BY_COLUMN, SQL_IS_UINTEGER)) ||  
+		if (Utility::isError(Poco::Data::ODBC::SQLSetStmtAttr(_rStmt, SQL_ATTR_PARAM_BIND_TYPE, SQL_PARAM_BIND_BY_COLUMN, SQL_IS_UINTEGER)) ||
 			Utility::isError(Poco::Data::ODBC::SQLSetStmtAttr(_rStmt, SQL_ATTR_PARAMSET_SIZE, (SQLPOINTER) length, SQL_IS_UINTEGER)))
 				throw StatementException(_rStmt, "SQLSetStmtAttr()");
 
