@@ -523,6 +523,9 @@ public:
 	bool isDateTime() const;
 		/// Returns true if stored value represents a date/time.
 
+	bool isUUID() const;
+		/// Returns true if stored value is a Poco::UUID.
+
 	std::size_t size() const;
 		/// Returns the size of this Var.
 		/// This function returns 0 when Var is empty, 1 for POD or the size (i.e. length)
@@ -737,7 +740,7 @@ inline const std::type_info& Var::type() const
 
 inline Var::ConstIterator Var::begin() const
 {
-	if (isEmpty()) return ConstIterator(const_cast<Var*>(this), true);
+	if (size() == 0) return ConstIterator(const_cast<Var*>(this), true);
 
 	return ConstIterator(const_cast<Var*>(this), false);
 }
@@ -749,7 +752,7 @@ inline Var::ConstIterator Var::end() const
 
 inline Var::Iterator Var::begin()
 {
-	if (isEmpty()) return Iterator(const_cast<Var*>(this), true);
+	if (size() == 0) return Iterator(const_cast<Var*>(this), true);
 
 	return Iterator(const_cast<Var*>(this), false);
 }
@@ -896,6 +899,13 @@ inline bool Var::isDateTime() const
 }
 
 
+inline bool Var::isUUID() const
+{
+	VarHolder* pHolder = content();
+	return pHolder ? pHolder->isUUID() : false;
+}
+
+
 inline std::size_t Var::size() const
 {
 	VarHolder* pHolder = content();
