@@ -13,7 +13,7 @@
 
 
 #include "Poco/Path_WIN32U.h"
-#include "Poco/Environment_WIN32.h"
+#include "Poco/Environment_WIN32U.h"
 #include "Poco/UnicodeConverter.h"
 #include "Poco/Buffer.h"
 #include "Poco/Exception.h"
