@@ -33,9 +33,13 @@ public:
 	void testSize();
 	void testDirectory();
 	void testCopy();
+	void testCopyFailIfDestinationFileExists();
 	void testMove();
+	void testMoveFailIfDestinationFileExists();
 	void testCopyDirectory();
+	void testCopyDirectoryFailIfExists();
 	void testRename();
+	void testRenameFailIfExists();
 	void testRootDir();
 	void testLongPath();
 	
