@@ -8,6 +8,11 @@
 //
 
 
+#if defined(_MSC_VER) && !defined(_CRT_SECURE_NO_WARNINGS)
+#define _CRT_SECURE_NO_WARNINGS
+#endif
+
+
 #include "LocalDateTimeTest.h"
 #include "CppUnit/TestCaller.h"
 #include "CppUnit/TestSuite.h"
@@ -24,6 +29,7 @@
 #include "wce_time.h"
 #endif
 
+
 using Poco::LocalDateTime;
 using Poco::DateTime;
 using Poco::Timestamp;
