@@ -38,18 +38,18 @@ void LogStreamTest::testLogStream()
 {
 	AutoPtr<TestChannel> pChannel = new TestChannel;
 	Logger& root = Logger::root();
-	root.setChannel(pChannel.get());
+	root.setChannel(pChannel);
 
 	LogStream ls(root);
 
 	ls << "information" << ' ' << 1 << std::endl;
-	assert (pChannel->list().begin()->getPriority() == Message::PRIO_INFORMATION);
-	assert (pChannel->list().begin()->getText() == "information 1");
+	assertTrue (pChannel->list().begin()->getPriority() == Message::PRIO_INFORMATION);
+	assertTrue (pChannel->list().begin()->getText() == "information 1");
 	pChannel->list().clear();
 
 	ls.error() << "error" << std::endl;
-	assert (pChannel->list().begin()->getPriority() == Message::PRIO_ERROR);
-	assert (pChannel->list().begin()->getText() == "error");
+	assertTrue (pChannel->list().begin()->getPriority() == Message::PRIO_ERROR);
+	assertTrue (pChannel->list().begin()->getText() == "error");
 	pChannel->list().clear();
 }
 
