@@ -27,15 +27,20 @@ namespace Poco {
 namespace Net {
 
 
-HTTPSessionFactory::HTTPSessionFactory():
-	_proxyPort(0)
+HTTPSessionFactory::HTTPSessionFactory()
 {
 }
 
 
-HTTPSessionFactory::HTTPSessionFactory(const std::string& proxyHost, Poco::UInt16 proxyPort):
-	_proxyHost(proxyHost),
-	_proxyPort(proxyPort)
+HTTPSessionFactory::HTTPSessionFactory(const std::string& proxyHost, Poco::UInt16 proxyPort)
+{
+	_proxyConfig.host = proxyHost;
+	_proxyConfig.port = proxyPort;
+}
+
+
+HTTPSessionFactory::HTTPSessionFactory(const HTTPClientSession::ProxyConfig& proxyConfig):
+	_proxyConfig(proxyConfig)
 {
 }
 
@@ -55,7 +60,7 @@ void HTTPSessionFactory::registerProtocol(const std::string& protocol, HTTPSessi
 
 	FastMutex::ScopedLock lock(_mutex);
 	std::pair<Instantiators::iterator, bool> tmp = _instantiators.insert(make_pair(protocol, InstantiatorInfo(pSessionInstantiator)));
-	if (!tmp.second) 
+	if (!tmp.second)
 	{
 		++tmp.first->second.cnt;
 		delete pSessionInstantiator;
@@ -66,7 +71,7 @@ void HTTPSessionFactory::registerProtocol(const std::string& protocol, HTTPSessi
 void HTTPSessionFactory::unregisterProtocol(const std::string& protocol)
 {
 	FastMutex::ScopedLock lock(_mutex);
-	
+
 	Instantiators::iterator it = _instantiators.find(protocol);
 	if (it != _instantiators.end())
 	{
@@ -84,7 +89,7 @@ void HTTPSessionFactory::unregisterProtocol(const std::string& protocol)
 bool HTTPSessionFactory::supportsProtocol(const std::string& protocol)
 {
 	FastMutex::ScopedLock lock(_mutex);
-	
+
 	Instantiators::iterator it = _instantiators.find(protocol);
 	return it != _instantiators.end();
 }
@@ -93,14 +98,13 @@ bool HTTPSessionFactory::supportsProtocol(const std::string& protocol)
 HTTPClientSession* HTTPSessionFactory::createClientSession(const Poco::URI& uri)
 {
 	FastMutex::ScopedLock lock(_mutex);
-	
+
 	if (uri.isRelative()) throw Poco::UnknownURISchemeException("Relative URIs are not supported by HTTPSessionFactory.");
 
 	Instantiators::iterator it = _instantiators.find(uri.getScheme());
 	if (it != _instantiators.end())
 	{
-		it->second.pIn->setProxy(_proxyHost, _proxyPort);
-		it->second.pIn->setProxyCredentials(_proxyUsername, _proxyPassword);
+		it->second.pIn->setProxyConfig(_proxyConfig);
 		return it->second.pIn->createClientSession(uri);
 	}
 	else throw Poco::UnknownURISchemeException(uri.getScheme());
@@ -111,8 +115,8 @@ void HTTPSessionFactory::setProxy(const std::string& host, Poco::UInt16 port)
 {
 	FastMutex::ScopedLock lock(_mutex);
 
-	_proxyHost = host;
-	_proxyPort = port;
+	_proxyConfig.host = host;
+	_proxyConfig.port = port;
 }
 
 
@@ -120,8 +124,16 @@ void HTTPSessionFactory::setProxyCredentials(const std::string& username, const
 {
 	FastMutex::ScopedLock lock(_mutex);
 
-	_proxyUsername = username;
-	_proxyPassword = password;
+	_proxyConfig.username = username;
+	_proxyConfig.password = password;
+}
+
+
+void HTTPSessionFactory::setProxyConfig(const HTTPClientSession::ProxyConfig& proxyConfig)
+{
+	FastMutex::ScopedLock lock(_mutex);
+
+	_proxyConfig = proxyConfig;
 }
 
 
