@@ -109,6 +109,20 @@ public:
 		_socketMap.erase(socket.impl());
 	}
 
+	bool has(const Socket& socket) const
+	{
+		Poco::FastMutex::ScopedLock lock(_mutex);
+		SocketImpl* sockImpl = socket.impl();
+		return sockImpl &&
+			(_socketMap.find(sockImpl) != _socketMap.end());
+	}
+
+	bool empty() const
+	{
+		Poco::FastMutex::ScopedLock lock(_mutex);
+		return _socketMap.empty();
+	}
+
 	void update(const Socket& socket, int mode)
 	{
 		poco_socket_t fd = socket.impl()->sockfd();
@@ -145,7 +159,10 @@ public:
 	{
 		PollSet::SocketModeMap result;
 
-		if (_socketMap.empty()) return result;
+		{
+			Poco::FastMutex::ScopedLock lock(_mutex);
+			if(_socketMap.empty()) return result;
+		}
 
 		Poco::Timespan remainingTime(timeout);
 		int rc;
@@ -186,9 +203,9 @@ public:
 	}
 
 private:
-	Poco::FastMutex _mutex;
-	int _epollfd;
-	std::map<void*, Socket> _socketMap;
+	mutable Poco::FastMutex         _mutex;
+	int                             _epollfd;
+	std::map<void*, Socket>         _socketMap;
 	std::vector<struct epoll_event> _events;
 };
 
@@ -197,7 +214,7 @@ private:
 
 
 //
-// BSD implementation using poll
+// BSD/Windows implementation using poll/WSAPoll
 //
 class PollSetImpl
 {
@@ -222,20 +239,32 @@ public:
 		_socketMap.erase(fd);
 	}
 
+	bool has(const Socket& socket) const
+	{
+		Poco::FastMutex::ScopedLock lock(_mutex);
+		SocketImpl* sockImpl = socket.impl();
+		return sockImpl &&
+			(_socketMap.find(sockImpl->sockfd()) != _socketMap.end());
+	}
+
+	bool empty() const
+	{
+		Poco::FastMutex::ScopedLock lock(_mutex);
+		return _socketMap.empty();
+	}
+
 	void update(const Socket& socket, int mode)
 	{
 		Poco::FastMutex::ScopedLock lock(_mutex);
 
 		poco_socket_t fd = socket.impl()->sockfd();
-		for (std::vector<pollfd>::iterator it = _pollfds.begin(); it != _pollfds.end(); ++it)
+		for (auto it = _pollfds.begin(); it != _pollfds.end(); ++it)
 		{
 			if (it->fd == fd)
 			{
 				it->events = 0;
-				if (mode & PollSet::POLL_READ)
-					it->events |= POLLIN;
-				if (mode & PollSet::POLL_WRITE)
-					it->events |= POLLOUT;
+				it->revents = 0;
+				setMode(it->fd, it->events, mode);
 			}
 		}
 	}
@@ -258,7 +287,7 @@ public:
 
 			if (!_removeSet.empty())
 			{
-				for (std::vector<pollfd>::iterator it = _pollfds.begin(); it != _pollfds.end();)
+				for (auto it = _pollfds.begin(); it != _pollfds.end();)
 				{
 					if (_removeSet.find(it->fd) != _removeSet.end())
 					{
@@ -270,17 +299,13 @@ public:
 			}
 
 			_pollfds.reserve(_pollfds.size() + _addMap.size());
-			for (std::map<poco_socket_t, int>::iterator it = _addMap.begin(); it != _addMap.end(); ++it)
+			for (auto it = _addMap.begin(); it != _addMap.end(); ++it)
 			{
 				pollfd pfd;
 				pfd.fd = it->first;
 				pfd.events = 0;
 				pfd.revents = 0;
-				if (it->second & PollSet::POLL_READ)
-					pfd.events |= POLLIN;
-				if (it->second & PollSet::POLL_WRITE)
-					pfd.events |= POLLOUT;
-
+				setMode(pfd.fd, pfd.events, it->second);
 				_pollfds.push_back(pfd);
 			}
 			_addMap.clear();
@@ -294,9 +319,15 @@ public:
 		{
 			Poco::Timestamp start;
 #ifdef _WIN32
-			rc = WSAPoll(&_pollfds[0], _pollfds.size(), static_cast<INT>(timeout.totalMilliseconds()));
+			rc = WSAPoll(&_pollfds[0], static_cast<ULONG>(_pollfds.size()), static_cast<INT>(remainingTime.totalMilliseconds()));
+			// see https://github.com/pocoproject/poco/issues/3248
+			if ((remainingTime > 0) && (rc > 0) && !hasSignaledFDs())
+			{
+				rc = -1;
+				WSASetLastError(WSAEINTR);
+			}
 #else
-			rc = ::poll(&_pollfds[0], _pollfds.size(), timeout.totalMilliseconds());
+			rc = ::poll(&_pollfds[0], _pollfds.size(), remainingTime.totalMilliseconds());
 #endif
 			if (rc < 0 && SocketImpl::lastError() == POCO_EINTR)
 			{
@@ -316,21 +347,25 @@ public:
 
 			if (!_socketMap.empty())
 			{
-				for (std::vector<pollfd>::iterator it = _pollfds.begin(); it != _pollfds.end(); ++it)
+				for (auto it = _pollfds.begin(); it != _pollfds.end(); ++it)
 				{
 					std::map<poco_socket_t, Socket>::const_iterator its = _socketMap.find(it->fd);
 					if (its != _socketMap.end())
 					{
-						if (it->revents & POLLIN)
+						if ((it->revents & POLLIN)
+#ifdef _WIN32
+						|| (it->revents & POLLHUP)
+#endif
+							)
 							result[its->second] |= PollSet::POLL_READ;
-						if (it->revents & POLLOUT)
+						if ((it->revents & POLLOUT)
+#ifdef _WIN32
+							&& (_wantPOLLOUT.find(it->fd) != _wantPOLLOUT.end())
+#endif
+							)
 							result[its->second] |= PollSet::POLL_WRITE;
 						if (it->revents & POLLERR)
 							result[its->second] |= PollSet::POLL_ERROR;
-#ifdef _WIN32
-						if (it->revents & POLLHUP)
-							result[its->second] |= PollSet::POLL_READ;
-#endif
 					}
 					it->revents = 0;
 				}
@@ -341,11 +376,55 @@ public:
 	}
 
 private:
-	Poco::FastMutex _mutex;
+
+#ifdef _WIN32
+
+	void setMode(poco_socket_t fd, short& target, int mode)
+	{
+		if (mode & PollSet::POLL_READ)
+			target |= POLLIN;
+
+		if (mode & PollSet::POLL_WRITE)
+			_wantPOLLOUT.insert(fd);
+		else
+			_wantPOLLOUT.erase(fd);
+		target |= POLLOUT;
+	}
+
+	bool hasSignaledFDs()
+	{
+		for (const auto& pollfd : _pollfds)
+		{
+			if ((pollfd.revents | POLLOUT) &&
+				(_wantPOLLOUT.find(pollfd.fd) != _wantPOLLOUT.end()))
+			{
+				return true;
+			}
+		}
+		return false;
+	}
+
+#else
+
+	void setMode(poco_socket_t fd, short& target, int mode)
+	{
+		if (mode & PollSet::POLL_READ)
+			target |= POLLIN;
+
+		if (mode & PollSet::POLL_WRITE)
+			target |= POLLOUT;
+	}
+
+#endif
+
+	mutable Poco::FastMutex         _mutex;
 	std::map<poco_socket_t, Socket> _socketMap;
-	std::map<poco_socket_t, int> _addMap;
-	std::set<poco_socket_t> _removeSet;
-	std::vector<pollfd> _pollfds;
+#ifdef _WIN32
+	std::set<poco_socket_t>         _wantPOLLOUT;
+#endif
+	std::map<poco_socket_t, int>    _addMap;
+	std::set<poco_socket_t>         _removeSet;
+	std::vector<pollfd>             _pollfds;
 };
 
 
@@ -361,28 +440,36 @@ public:
 	void add(const Socket& socket, int mode)
 	{
 		Poco::FastMutex::ScopedLock lock(_mutex);
-
 		_map[socket] = mode;
 	}
 
 	void remove(const Socket& socket)
 	{
 		Poco::FastMutex::ScopedLock lock(_mutex);
-
 		_map.erase(socket);
 	}
 
+	bool has(const Socket& socket) const
+	{
+		Poco::FastMutex::ScopedLock lock(_mutex);
+		return _map.find(socket) != _map.end();
+	}
+
+	bool empty() const
+	{
+		Poco::FastMutex::ScopedLock lock(_mutex);
+		return _map.empty();
+	}
+
 	void update(const Socket& socket, int mode)
 	{
 		Poco::FastMutex::ScopedLock lock(_mutex);
-
 		_map[socket] = mode;
 	}
 
 	void clear()
 	{
 		Poco::FastMutex::ScopedLock lock(_mutex);
-
 		_map.clear();
 	}
 
@@ -400,7 +487,7 @@ public:
 		{
 			Poco::FastMutex::ScopedLock lock(_mutex);
 
-			for (PollSet::SocketModeMap::const_iterator it = _map.begin(); it != _map.end(); ++it)
+			for (auto it = _map.begin(); it != _map.end(); ++it)
 			{
 				poco_socket_t fd = it->first.impl()->sockfd();
 				if (fd != POCO_INVALID_SOCKET && it->second)
@@ -451,7 +538,7 @@ public:
 		{
 			Poco::FastMutex::ScopedLock lock(_mutex);
 
-			for (PollSet::SocketModeMap::const_iterator it = _map.begin(); it != _map.end(); ++it)
+			for (auto it = _map.begin(); it != _map.end(); ++it)
 			{
 				poco_socket_t fd = it->first.impl()->sockfd();
 				if (fd != POCO_INVALID_SOCKET)
@@ -476,8 +563,8 @@ public:
 	}
 
 private:
-	Poco::FastMutex _mutex;
-	PollSet::SocketModeMap _map;
+	mutable Poco::FastMutex _mutex;
+	PollSet::SocketModeMap  _map;
 };
 
 
@@ -514,6 +601,18 @@ void PollSet::update(const Socket& socket, int mode)
 }
 
 
+bool PollSet::has(const Socket& socket) const
+{
+	return _pImpl->has(socket);
+}
+
+
+bool PollSet::empty() const
+{
+	return _pImpl->empty();
+}
+
+
 void PollSet::clear()
 {
 	_pImpl->clear();
