@@ -51,6 +51,11 @@
 #endif
 
 
+#if defined(_MSC_VER)
+#pragma warning(disable:4996) // deprecation warnings
+#endif
+
+
 using Poco::IOException;
 using Poco::TimeoutException;
 using Poco::InvalidArgumentException;
