@@ -39,14 +39,14 @@ void DNSTest::testHostByName()
 {
 	HostEntry he1 = DNS::hostByName("aliastest.pocoproject.org");
 	// different systems report different canonical names, unfortunately.
-	assert (he1.name() == "dnstest.pocoproject.org" || he1.name() == "aliastest.pocoproject.org");
+	assertTrue (he1.name() == "dnstest.pocoproject.org" || he1.name() == "aliastest.pocoproject.org");
 #if !defined(POCO_HAVE_ADDRINFO)
 	// getaddrinfo() does not report any aliases
-	assert (!he1.aliases().empty());
-	assert (he1.aliases()[0] == "aliastest.pocoproject.org");
+	assertTrue (!he1.aliases().empty());
+	assertTrue (he1.aliases()[0] == "aliastest.pocoproject.org");
 #endif
-	assert (he1.addresses().size() >= 1);
-	assert (he1.addresses()[0].toString() == "1.2.3.4");
+	assertTrue (he1.addresses().size() >= 1);
+	assertTrue (he1.addresses()[0].toString() == "1.2.3.4");
 
 	try
 	{
@@ -66,10 +66,10 @@ void DNSTest::testHostByAddress()
 {
 	IPAddress ip1("80.122.195.86");
 	HostEntry he1 = DNS::hostByAddress(ip1);
-	assert (he1.name() == "mailhost.appinf.com");
-	assert (he1.aliases().empty());
-	assert (he1.addresses().size() >= 1);
-	assert (he1.addresses()[0].toString() == "80.122.195.86");
+	assertTrue (he1.name() == "mailhost.appinf.com");
+	assertTrue (he1.aliases().empty());
+	assertTrue (he1.addresses().size() >= 1);
+	assertTrue (he1.addresses()[0].toString() == "80.122.195.86");
 
 	IPAddress ip2("10.0.244.253");
 	try
@@ -88,94 +88,105 @@ void DNSTest::testHostByAddress()
 
 void DNSTest::testResolve()
 {
+	HostEntry he1 = DNS::hostByName("localhost");
+
+	auto a = he1.addresses();
+	sort(a.begin(), a.end());
+	auto itA = std::unique(a.begin(), a.end());
+	assertTrue (itA == a.end());
+
+	auto b = he1.aliases();
+	sort(b.begin(), b.end());
+	auto itB = std::unique(b.begin(), b.end());
+	assertTrue (itB == b.end());
 }
 
 
 void DNSTest::testEncodeIDN()
 {
 	std::string idn("d\xc3\xb6m\xc3\xa4in.example"); // d"om"ain.example 
-	assert (DNS::isIDN(idn));
-	assert (DNS::encodeIDN(idn) == "xn--dmin-moa0i.example");
+	assertTrue (DNS::isIDN(idn));
+	assertTrue (DNS::encodeIDN(idn) == "xn--dmin-moa0i.example");
 
 	idn = ".d\xc3\xb6m\xc3\xa4in.example"; // .d"om"ain.example 
-	assert(DNS::isIDN(idn));
-	assert(DNS::encodeIDN(idn) == ".xn--dmin-moa0i.example");
+	assertTrue (DNS::isIDN(idn));
+	assertTrue (DNS::encodeIDN(idn) == ".xn--dmin-moa0i.example");
 
 	idn = "d\xc3\xb6m\xc3\xa4in.example."; // .d"om"ain.example.
-	assert(DNS::isIDN(idn));
-	assert(DNS::encodeIDN(idn) == "xn--dmin-moa0i.example.");
+	assertTrue (DNS::isIDN(idn));
+	assertTrue (DNS::encodeIDN(idn) == "xn--dmin-moa0i.example.");
 
 	idn = "d\xc3\xb6m\xc3\xa4in"; // d"om"ain
-	assert(DNS::isIDN(idn));
-	assert(DNS::encodeIDN(idn) == "xn--dmin-moa0i");
+	assertTrue (DNS::isIDN(idn));
+	assertTrue (DNS::encodeIDN(idn) == "xn--dmin-moa0i");
 
 	idn = "\xc3\xa4""aaa.example"; // "aaaa.example
-	assert (DNS::isIDN(idn));
-	assert (DNS::encodeIDN(idn) == "xn--aaa-pla.example");
+	assertTrue (DNS::isIDN(idn));
+	assertTrue (DNS::encodeIDN(idn) == "xn--aaa-pla.example");
 
 	idn = "a\xc3\xa4""aa.example"; // a"aaa.example
-	assert(DNS::isIDN(idn));
-	assert(DNS::encodeIDN(idn) == "xn--aaa-qla.example");
+	assertTrue (DNS::isIDN(idn));
+	assertTrue (DNS::encodeIDN(idn) == "xn--aaa-qla.example");
 
 	idn = "foo.\xc3\xa2""bcd\xc3\xa9""f.example"; // foo.^abcd'ef.example
-	assert(DNS::isIDN(idn));
-	assert(DNS::encodeIDN(idn) == "foo.xn--bcdf-9na9b.example");
+	assertTrue (DNS::isIDN(idn));
+	assertTrue (DNS::encodeIDN(idn) == "foo.xn--bcdf-9na9b.example");
 
 	idn = "\xe2\x98\x83.example"; // <snowman>.example
-	assert(DNS::isIDN(idn));
-	assert(DNS::encodeIDN(idn) == "xn--n3h.example");
+	assertTrue (DNS::isIDN(idn));
+	assertTrue (DNS::encodeIDN(idn) == "xn--n3h.example");
 
 	idn = "\xe2\x98\x83."; // <snowman>.
-	assert(DNS::isIDN(idn));
-	assert(DNS::encodeIDN(idn) == "xn--n3h.");
+	assertTrue (DNS::isIDN(idn));
+	assertTrue (DNS::encodeIDN(idn) == "xn--n3h.");
 
 	idn = "\xe2\x98\x83"; // <snowman>
-	assert(DNS::isIDN(idn));
-	assert(DNS::encodeIDN(idn) == "xn--n3h");
+	assertTrue (DNS::isIDN(idn));
+	assertTrue (DNS::encodeIDN(idn) == "xn--n3h");
 
 	std::string dn = "www.pocoproject.org";
-	assert (!DNS::isIDN(dn));
-	assert (DNS::encodeIDN(dn) == "www.pocoproject.org");
+	assertTrue (!DNS::isIDN(dn));
+	assertTrue (DNS::encodeIDN(dn) == "www.pocoproject.org");
 }
 
 
 void DNSTest::testDecodeIDN()
 {
 	std::string enc("xn--dmin-moa0i.example");
-	assert (DNS::isEncodedIDN(enc));
-	assert (DNS::decodeIDN(enc) == "d\xc3\xb6m\xc3\xa4in.example"); // d"om"ain.example 
+	assertTrue (DNS::isEncodedIDN(enc));
+	assertTrue (DNS::decodeIDN(enc) == "d\xc3\xb6m\xc3\xa4in.example"); // d"om"ain.example 
 
 	enc = ".xn--dmin-moa0i.example";
-	assert(DNS::isEncodedIDN(enc));
-	assert(DNS::decodeIDN(enc) == ".d\xc3\xb6m\xc3\xa4in.example"); // .d"om"ain.example 
+	assertTrue (DNS::isEncodedIDN(enc));
+	assertTrue (DNS::decodeIDN(enc) == ".d\xc3\xb6m\xc3\xa4in.example"); // .d"om"ain.example 
 
 	enc = "xn--dmin-moa0i.example.";
-	assert(DNS::isEncodedIDN(enc));
-	assert(DNS::decodeIDN(enc) == "d\xc3\xb6m\xc3\xa4in.example."); // d"om"ain.example.
+	assertTrue (DNS::isEncodedIDN(enc));
+	assertTrue (DNS::decodeIDN(enc) == "d\xc3\xb6m\xc3\xa4in.example."); // d"om"ain.example.
 
 	enc = "xn--dmin-moa0i";
-	assert(DNS::isEncodedIDN(enc));
-	assert(DNS::decodeIDN(enc) == "d\xc3\xb6m\xc3\xa4in"); // d"om"ain
+	assertTrue (DNS::isEncodedIDN(enc));
+	assertTrue (DNS::decodeIDN(enc) == "d\xc3\xb6m\xc3\xa4in"); // d"om"ain
 
 	enc = "foo.xn--bcdf-9na9b.example";
-	assert (DNS::isEncodedIDN(enc));
-	assert (DNS::decodeIDN(enc) == "foo.\xc3\xa2""bcd\xc3\xa9""f.example"); // foo.^abcd'ef.example
+	assertTrue (DNS::isEncodedIDN(enc));
+	assertTrue (DNS::decodeIDN(enc) == "foo.\xc3\xa2""bcd\xc3\xa9""f.example"); // foo.^abcd'ef.example
 
 	enc = "xn--n3h.example";
-	assert (DNS::isEncodedIDN(enc));
-	assert (DNS::decodeIDN(enc) == "\xe2\x98\x83.example"); // <snowman>.example
+	assertTrue (DNS::isEncodedIDN(enc));
+	assertTrue (DNS::decodeIDN(enc) == "\xe2\x98\x83.example"); // <snowman>.example
 
 	enc = "xn--n3h.";
-	assert(DNS::isEncodedIDN(enc));
-	assert(DNS::decodeIDN(enc) == "\xe2\x98\x83."); // <snowman>.
+	assertTrue (DNS::isEncodedIDN(enc));
+	assertTrue (DNS::decodeIDN(enc) == "\xe2\x98\x83."); // <snowman>.
 
 	enc = "xn--n3h";
-	assert(DNS::isEncodedIDN(enc));
-	assert(DNS::decodeIDN(enc) == "\xe2\x98\x83"); // <snowman>
+	assertTrue (DNS::isEncodedIDN(enc));
+	assertTrue (DNS::decodeIDN(enc) == "\xe2\x98\x83"); // <snowman>
 
 	std::string dn = "www.pocoproject.org";
-	assert (!DNS::isEncodedIDN(dn));
-	assert (DNS::decodeIDN(dn) == "www.pocoproject.org");
+	assertTrue (!DNS::isEncodedIDN(dn));
+	assertTrue (DNS::decodeIDN(dn) == "www.pocoproject.org");
 }
 
 
