@@ -36,15 +36,22 @@ public:
 	Poco::UInt16 port() const;
 		/// Returns the port the echo server is
 		/// listening on.
-		
+
 	void run();
 		/// Does the work.
-		
+
+	void stop();
+		/// Sets the stop flag.
+
+	bool done();
+		/// Retruns true if if server is done.
+
 private:
 	Poco::Net::ServerSocket _socket;
 	Poco::Thread _thread;
 	Poco::Event  _ready;
 	bool         _stop;
+	bool         _done;
 };
 
 
