@@ -32,6 +32,9 @@ using Poco::Delegate;
 using Poco::AutoPtr;
 
 
+Poco::FastMutex ICMPClientTest::_mutex;
+
+
 ICMPClientTest::ICMPClientTest(const std::string& name): 
 	CppUnit::TestCase(name)
 {
@@ -45,51 +48,55 @@ ICMPClientTest::~ICMPClientTest()
 
 void ICMPClientTest::testPing()
 {
-	assert(ICMPClient::pingIPv4("127.0.0.1") > 0);
+	assertTrue (ICMPClient::pingIPv4("127.0.0.1") > 0);
 
 	Poco::Net::ICMPClient icmpClient(IPAddress::IPv4);
 
 	registerDelegates(icmpClient);
 
-	assert(icmpClient.ping("127.0.0.1") > 0);
+	assertTrue (icmpClient.ping("127.0.0.1") > 0);
 #if POCO_OS == POCO_OS_ANDROID
-	assert(icmpClient.ping("10.0.2.15", 4) > 0);
-	assert(icmpClient.ping("10.0.2.2", 4) > 0);
+	assertTrue (icmpClient.ping("10.0.2.15", 4) > 0);
+	assertTrue (icmpClient.ping("10.0.2.2", 4) > 0);
 #else
-	assert(icmpClient.ping("www.appinf.com", 4) > 0);
+	assertTrue (icmpClient.ping("www.appinf.com", 4) > 0);
 
 	// warning: may fail depending on the existence of the addresses at test site
 	// if so, adjust accordingly (i.e. specify non-existent or unreachable IP addresses)
-	assert(0 == icmpClient.ping("192.168.243.1"));
-	assert(0 == icmpClient.ping("10.11.12.13"));
+	assertTrue (0 == icmpClient.ping("192.168.243.1"));
+	assertTrue (0 == icmpClient.ping("10.11.12.13"));
 #endif
 
 	unregisterDelegates(icmpClient);
+	// wait for delegates to finish printing
+	Poco::FastMutex::ScopedLock l(_mutex);
 }
 
 
 void ICMPClientTest::testBigPing()
 {
-	assert(ICMPClient::pingIPv4("127.0.0.1", 1, 96) > 0);
+	assertTrue (ICMPClient::pingIPv4("127.0.0.1", 1, 96) > 0);
 
 	Poco::Net::ICMPClient icmpClient(IPAddress::IPv4, 96);
 
 	registerDelegates(icmpClient);
 
-	assert(icmpClient.ping("127.0.0.1", 1) > 0);
+	assertTrue (icmpClient.ping("127.0.0.1", 1) > 0);
 #if POCO_OS == POCO_OS_ANDROID
-	assert(icmpClient.ping("10.0.2.15", 4) > 0);
-	assert(icmpClient.ping("10.0.2.2", 4) > 0);
+	assertTrue (icmpClient.ping("10.0.2.15", 4) > 0);
+	assertTrue (icmpClient.ping("10.0.2.2", 4) > 0);
 #else
-	assert(icmpClient.ping("www.appinf.com", 4) > 0);
+	assertTrue (icmpClient.ping("www.appinf.com", 4) > 0);
 
 	// warning: may fail depending on the existence of the addresses at test site
 	// if so, adjust accordingly (i.e. specify non-existent or unreachable IP addresses)
-	assert(0 == icmpClient.ping("192.168.243.1"));
-	assert(0 == icmpClient.ping("10.11.12.13"));
+	assertTrue (0 == icmpClient.ping("192.168.243.1"));
+	assertTrue (0 == icmpClient.ping("10.11.12.13"));
 #endif
 
 	unregisterDelegates(icmpClient);
+	// wait for delegates to finish printing
+	Poco::FastMutex::ScopedLock l(_mutex);
 }
 
 
@@ -123,6 +130,7 @@ void ICMPClientTest::tearDown()
 
 void ICMPClientTest::onBegin(const void* pSender, ICMPEventArgs& args)
 {
+	Poco::FastMutex::ScopedLock l(_mutex);
 	std::ostringstream os;
 	os << std::endl << "Pinging " << args.hostName() << " [" << args.hostAddress() << "] with " 
 		<< args.dataSize() << " bytes of data:" 
@@ -133,6 +141,7 @@ void ICMPClientTest::onBegin(const void* pSender, ICMPEventArgs& args)
 
 void ICMPClientTest::onReply(const void* pSender, ICMPEventArgs& args)
 {
+	Poco::FastMutex::ScopedLock l(_mutex);
 	std::ostringstream os;
 	os << "Reply from " << args.hostAddress()
 		<< " bytes=" << args.dataSize() 
@@ -144,6 +153,7 @@ void ICMPClientTest::onReply(const void* pSender, ICMPEventArgs& args)
 
 void ICMPClientTest::onError(const void* pSender, ICMPEventArgs& args)
 {
+	Poco::FastMutex::ScopedLock l(_mutex);
 	std::ostringstream os;
 	os << args.error();
 	std::cerr << os.str() << std::endl;
@@ -152,6 +162,7 @@ void ICMPClientTest::onError(const void* pSender, ICMPEventArgs& args)
 
 void ICMPClientTest::onEnd(const void* pSender, ICMPEventArgs& args)
 {
+	Poco::FastMutex::ScopedLock l(_mutex);
 	std::ostringstream os;
 	int received = args.received();
 	os << std::endl << "--- Ping statistics for " << args.hostAddress() << " ---"
