@@ -10,6 +10,7 @@
 
 #include "ICMPClientTestSuite.h"
 #include "ICMPClientTest.h"
+#include "ICMPSocketTest.h"
 
 
 CppUnit::Test* ICMPClientTestSuite::suite()
@@ -17,6 +18,7 @@ CppUnit::Test* ICMPClientTestSuite::suite()
 	CppUnit::TestSuite* pSuite = new CppUnit::TestSuite("ICMPClientTestSuite");
 
 	pSuite->addTest(ICMPClientTest::suite());
+	pSuite->addTest(ICMPSocketTest::suite());
 
 	return pSuite;
 }
